@@ -1,9 +1,9 @@
 package Net::DNS::RR::NSEC;
 
 #
-# $Id: NSEC.pm 1528 2017-01-18 21:44:58Z willem $
+# $Id: NSEC.pm 1597 2017-09-22 08:04:02Z willem $
 #
-our $VERSION = (qw$LastChangedRevision: 1528 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1597 $)[1];
 
 
 use strict;
@@ -36,7 +36,7 @@ sub _decode_rdata {			## decode rdata from wire-format octet string
 sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
-	my $nxtdname = $self->{nxtdname} || return '';
+	my $nxtdname = $self->{nxtdname};
 	join '', $nxtdname->encode(), $self->{typebm};
 }
 
@@ -44,7 +44,7 @@ sub _encode_rdata {			## encode rdata as wire-format octet string
 sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	my $nxtdname = $self->{nxtdname} || return '';
+	my $nxtdname = $self->{nxtdname};
 	my @rdata = ( $nxtdname->string(), $self->typelist );
 }
 
