@@ -1,10 +1,9 @@
 package Net::DNS::ZoneFile;
 
 #
-# $Id: ZoneFile.pm 1464 2016-03-03 13:00:22Z willem $
+# $Id: ZoneFile.pm 1526 2017-01-16 09:17:54Z willem $
 #
-use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1464 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1526 $)[1];
 
 
 =head1 NAME
@@ -44,9 +43,10 @@ automatically to all subsequent records.
 
 
 use strict;
+use warnings;
 use integer;
 use Carp;
-use FileHandle;
+use IO::File;
 
 use constant PERLIO => defined eval 'require PerlIO';
 
@@ -61,7 +61,7 @@ require Net::DNS::RR;
 
     $zonefile = new Net::DNS::ZoneFile( 'filename', ['example.com'] );
 
-    $handle   = new FileHandle( 'filename', '<:encoding(ISO8859-7)' );
+    $handle   = new IO::File( 'filename', '<:encoding(ISO8859-7)' );
     $zonefile = new Net::DNS::ZoneFile( $handle, ['example.com'] );
 
 The new() constructor returns a Net::DNS::ZoneFile object which
@@ -72,7 +72,7 @@ exhausted or all references to the ZoneFile object cease to exist.
 
 The optional second argument specifies $ORIGIN for the zone file.
 
-Character encoding is specified indirectly by creating a FileHandle
+Character encoding is specified indirectly by creating a file handle
 with the desired encoding layer, which is then passed as an argument
 to new(). The specified encoding is propagated to files introduced
 by $include directives.
@@ -86,12 +86,14 @@ sub new {
 
 	if ( ref($file) ) {
 		$self->{filename} = $self->{handle} = $file;
-		return $self if ref($file) =~ /FileHandle|IO::File|GLOB|Text/;
+		$self->{fileopen} = {};
+		return $self if ref($file) =~ /IO::File|FileHandle|GLOB|Text/;
 		croak 'argument not a file handle';
 	}
 
 	$self->{filename} = $file ||= '';
-	$self->{handle} = new FileHandle($file) or croak qq($! "$file");
+	$self->{handle} = new IO::File($file) or croak qq($! "$file");
+	$self->{fileopen}{$file}++;
 	return $self;
 }
 
@@ -142,9 +144,9 @@ sub read {
 
     $filename = $zonefile->name;
 
-Returns the name of the zone file from which RRs will be read.
-$INCLUDE directives will cause this to differ from the filename
-argument supplied when the object was created.
+Returns the name of the current zone file.
+Embedded $INCLUDE directives will cause this to differ from the
+filename argument supplied when the object was created.
 
 =cut
 
@@ -204,10 +206,12 @@ the compatibility interface described below.
 
     use Net::DNS::ZoneFile;
 
+    $listref = Net::DNS::ZoneFile->read( $filename );
     $listref = Net::DNS::ZoneFile->read( $filename, $include_dir );
 
     $listref = Net::DNS::ZoneFile->readfh( $handle, $include_dir );
 
+    $listref = Net::DNS::ZoneFile->parse(  $string );
     $listref = Net::DNS::ZoneFile->parse(  $string, $include_dir );
     $listref = Net::DNS::ZoneFile->parse( \$string, $include_dir );
 
@@ -236,7 +240,7 @@ error is encountered by the parser.
 
 =cut
 
-use vars qw($include_dir);		## dynamically scoped
+our $include_dir;			## dynamically scoped
 
 sub _filename {				## rebase unqualified filename
 	my $name = shift;
@@ -244,6 +248,7 @@ sub _filename {				## rebase unqualified filename
 	return $name unless $include_dir;
 	require File::Spec;
 	return $name if File::Spec->file_name_is_absolute($name);
+	return $name if -f $name;
 	return File::Spec->catfile( $include_dir, $name );
 }
 
@@ -273,20 +278,11 @@ sub _read {
 
 	use overload ( '<>' => 'readline' );
 
-	use constant OVERLOAD_OK => scalar eval 'no integer; $] > 5.006';
-
 	sub new {
 		my $self = bless {}, shift;
 		my $data = shift;
 		$self->{data} = [split /\n/, ref($data) ? $$data : $data];
-
-		return OVERLOAD_OK ? $self : do {		# Plan B
-			require IO::File;
-			my $fh = IO::File->new_tmpfile() or die "$!";
-			while ( my $line = $self->readline ) { print $fh $line, "\n"; }
-			seek $fh, 0, 0;
-			return $fh;
-		};
+		return $self;
 	}
 
 	sub readline {
@@ -348,8 +344,6 @@ sub parse {
 
 	use overload ( '<>' => 'readline' );
 
-	use constant OVERLOAD_OK => scalar eval 'no integer; $] > 5.006';
-
 	sub new {
 		my $self = bless {}, shift;
 		my ( $range, $template, $line ) = @_;
@@ -366,14 +360,7 @@ sub parse {
 		$self->{count} = int( ( $last - $first ) / $step ) + 1;
 
 		@{$self}{qw(instant step template line)} = ( $first, $step, $template, $line );
-
-		return OVERLOAD_OK ? $self : do {		# Plan B
-			require IO::File;
-			my $fh = IO::File->new_tmpfile() or die "$!";
-			while ( my $line = $self->readline ) { print $fh $line, "\n"; }
-			seek $fh, 0, 0;
-			return $fh;
-		};
+		return $self;
 	}
 
 	sub readline {
@@ -427,7 +414,7 @@ sub _generate {				## expand $GENERATE into input stream
 
 	my $handle = new Net::DNS::ZoneFile::Generator( $range, $template, $self->line );
 
-	delete $self->{latest};					# forbid empty owner field
+	delete $self->{latest};					# forget previous owner
 	$self->{parent} = bless {%$self}, ref($self);		# save state, create link
 	$self->{handle} = $handle;
 }
@@ -515,7 +502,8 @@ sub _getRR {				## get RR from current source
 	my $context = $self->{context};
 	my $rr = &$context( sub { Net::DNS::RR->_new_string($_) } );
 
-	$rr->{owner} = $self->{latest}->{owner} if $noname;	# overwrite placeholder
+	my $latest = $self->{latest};				# overwrite placeholder
+	$rr->{owner} = $latest->{owner} if $noname && $latest;
 
 	$self->{class} = $rr->class unless $self->{class};	# propagate RR class
 	$rr->class( $self->{class} );
@@ -532,13 +520,17 @@ sub _include {				## open $INCLUDE file
 	my $file = _filename(shift);
 	my $root = shift;
 
-	my @discipline = PERLIO ? ( join ':', '<', PerlIO::get_layers $self->{handle} ) : ();
-	my $handle = new FileHandle( $file, @discipline ) or croak qq($! "$file");
+	my $opened = {%{$self->{fileopen}}};
+	croak qq(recursive \$INCLUDE $file) if $opened->{$file}++;
 
-	delete $self->{latest};					# forbid empty owner field
+	my @discipline = PERLIO ? ( join ':', '<', PerlIO::get_layers $self->{handle} ) : ();
+	my $handle = new IO::File( $file, @discipline ) or croak qq($! "$file");
+
+	delete $self->{latest};					# forget previous owner
 	$self->{parent} = bless {%$self}, ref($self);		# save state, create link
-	$self->{context} = origin Net::DNS::Domain($root) if $root;
+	$self->{context}  = origin Net::DNS::Domain($root) if $root;
 	$self->{filename} = $file;
+	$self->{fileopen} = $opened;
 	return $self->{handle} = $handle;
 }
 
@@ -546,7 +538,7 @@ sub _include {				## open $INCLUDE file
 sub _origin {				## change $ORIGIN (scope: current file)
 	my $self = shift;
 	$self->{context} = origin Net::DNS::Domain(shift);
-	delete $self->{latest};					# forbid empty owner field
+	delete $self->{latest};					# forget previous owner
 }
 
 
